@@ -1,14 +1,9 @@
 package Tapper::Remote;
-# git description: v4.1.0-1-g7b671d3
+# git description: v4.1.1-3-gd09d5f0
 
-BEGIN {
-  $Tapper::Remote::AUTHORITY = 'cpan:TAPPER';
-}
-{
-  $Tapper::Remote::VERSION = '4.1.1';
-}
+our $AUTHORITY = 'cpan:TAPPER';
 # ABSTRACT: Tapper - Common functionality for remote automation libs
-
+$Tapper::Remote::VERSION = '5.0.0';
 use warnings;
 use strict;
 use Moose;
@@ -27,9 +22,10 @@ sub BUILD
 1; # End of Tapper::Remote
 
 __END__
+
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -46,17 +42,26 @@ base image for all modules of the project.
 
 Initialize config.
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 AMD OSRC Tapper Team <tapper@amd64.org>
 
+=item *
+
+Tapper Team <tapper-ops@amazon.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 by Advanced Micro Devices, Inc..
+This software is Copyright (c) 2016 by Advanced Micro Devices, Inc..
 
 This is free software, licensed under:
 
   The (two-clause) FreeBSD License
 
 =cut
-
