@@ -1,11 +1,6 @@
 package Tapper::Remote::Config;
-BEGIN {
-  $Tapper::Remote::Config::AUTHORITY = 'cpan:TAPPER';
-}
-{
-  $Tapper::Remote::Config::VERSION = '4.1.1';
-}
-
+our $AUTHORITY = 'cpan:TAPPER';
+$Tapper::Remote::Config::VERSION = '5.0.0';
 use strict;
 use warnings;
 
@@ -107,9 +102,10 @@ sub get_local_data
 1;
 
 __END__
+
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -153,17 +149,26 @@ so on.
 @return success - hash reference containing the config
 @return error   - error string
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 AMD OSRC Tapper Team <tapper@amd64.org>
 
+=item *
+
+Tapper Team <tapper-ops@amazon.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 by Advanced Micro Devices, Inc..
+This software is Copyright (c) 2016 by Advanced Micro Devices, Inc..
 
 This is free software, licensed under:
 
   The (two-clause) FreeBSD License
 
 =cut
-
